==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-hub-connector/dictionaries/es_cr.dict.itop-hub-connector.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 *
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', [
	'Menu:iTopHub' => 'iTop Hub',
	'Menu:iTopHub:BrowseExtensions' => 'Obtener extensiones de iTop Hub',
	'Menu:iTopHub:BrowseExtensions+' => 'Navegue por más extensiones en iTop Hub',
	'Menu:iTopHub:BrowseExtensions:Description' => '<p>Vea en "iTop Hub’s store", su único lugar para encontrar extensiones de '.ITOP_APPLICATION_SHORT.'.<br>Encuentre aquellas que le ayuden a personalizar y adaptar '.ITOP_APPLICATION_SHORT.' a sus procesos.<br><br>Mediante la conexión al Hub desde esta página, usted compartirá información acerca de esta instancia de '.ITOP_APPLICATION_SHORT.' en el Hub.</p>',
	'Menu:iTopHub:MyExtensions' => 'Extensiones instaladas',
	'Menu:iTopHub:MyExtensions+' => 'Vea la lista de extensiones instalada en esta instancia de '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:Register' => 'Conectar a iTop Hub',
	'Menu:iTopHub:Register+' => 'Ir a iTop Hub para actualizar su instancia de '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:Register:Description' => '<p>Obtenga acceso a la plataforma comunitaria iTop Hub!<br>Encuentre todo el contenido e información que necesite, adminitre sus instancias a través de herramientas personalizadas e instale más extensiones.<br><br>Mediante la conexión al Hub desde esta página, usted compartirá información acerca de esta instancia de '.ITOP_APPLICATION_SHORT.' en el Hub.</p>',
	'UI:About:RemoteExtensionSource' => 'iTop Hub',
	'iTopHub:AutoSubmit' => 'No me pregunte otra vez. Siguiente ocasión ir automáticamente a iTop Hub.',
	'iTopHub:BackupFailed' => 'Respaldo Fallido!',
	'iTopHub:BackupFreeDiskSpaceIn' => '%1$s espacio libre en disco en %2$s.',
	'iTopHub:BackupOk' => 'Respaldo Ok.',
	'iTopHub:CloseBtn' => 'Cerrar',
	'iTopHub:CompiledOK' => 'Compilación éxitosa.',
	'iTopHub:ConfigurationSafelyReverted' => 'Error detectado durante la instalación!<br>La configuración de '.ITOP_APPLICATION_SHORT.' NO fue modificada.',
	'iTopHub:DBBackupLabel' => 'Respaldo de Instancia',
	'iTopHub:DBBackupSentence' => 'Realice un respaldo de la base de datos y configuración de '.ITOP_APPLICATION_SHORT.' antes de actualizar.',
	'iTopHub:DatabaseBackupProgress' => 'Respaldo de Instancia...',
	'iTopHub:DeployBtn' => 'Instalar !',
	'iTopHub:Explanation' => 'Dando click a este botón, usted será redireccionado a iTop Hub.',
	'iTopHub:ExtensionCategory:Manual' => 'Extensiones instaladas manualmente',
	'iTopHub:ExtensionCategory:Manual+' => 'Las siguientes extensiones fueron instaladas copiandolas manualmente en el directorio %1$s de '.ITOP_APPLICATION_SHORT.':',
	'iTopHub:ExtensionCategory:Remote' => 'Extensiones instaladas desde iTop Hub',
	'iTopHub:ExtensionCategory:Remote+' => 'Las siguientes extensiones fueron instaladas de iTop Hub:',
	'iTopHub:ExtensionNotInstalled' => 'No instalada',
	'iTopHub:FailAuthent' => 'Autenticación fallida para esta acciónn.',
	'iTopHub:FailedToCheckFreeDiskSpace' => 'Falló en revisar disponibilidad de espacio libre en disco.',
	'iTopHub:GetMoreExtensions' => 'Obtener extensiones de iTop Hub...',
	'iTopHub:GoBackToITopBtn' => 'Regresar a '.ITOP_APPLICATION_SHORT,
	'iTopHub:GoBtn' => 'Ir a iTop Hub',
	'iTopHub:GoBtn:Tooltip' => 'Ir a www.itophub.io',
	'iTopHub:InstallationEffect:Downgrade' => 'Se <b>DEGRADARÄ</b> de la versión %1$s a la versión %2$s.',
	'iTopHub:InstallationEffect:Install' => 'Version: %1$s será instalada.',
	'iTopHub:InstallationEffect:MissingDependencies' => 'Esta extensión no puede ser instalad porque no cumple con las dependencias.',
	'iTopHub:InstallationEffect:MissingDependencies_Details' => 'La extensión require el/los módulo(s): %1$s',
	'iTopHub:InstallationEffect:NoChange' => 'Version: %1$s ya está instalada. Nada por cambiar.',
	'iTopHub:InstallationEffect:Upgrade' => 'Se <b>actualizará</b> de la versión %1$s a la versión %2$s.',
	'iTopHub:InstallationProgress:DatabaseBackup' => 'Respaldo de Instancia de '.ITOP_APPLICATION_SHORT.'...',
	'iTopHub:InstallationProgress:ExtensionsInstallation' => 'Instalación de extensiones',
	'iTopHub:InstallationProgress:InstallationSuccessful' => '¡Instalación éxitosa!',
	'iTopHub:InstallationStatus:Installed' => 'Instalada',
	'iTopHub:InstallationStatus:Installed_Version' => '%1$s versión: %2$s.',
	'iTopHub:InstallationStatus:Version_NotInstalled' => 'Versión %1$s <b>NO</b> está instalada.',
	'iTopHub:InstallationWelcome' => 'Instalación de las extensiones descargadas de iTop Hub',
	'iTopHub:InstalledExtensions' => 'Extensiones instaladas en esta instancia',
	'iTopHub:Landing:Install' => 'Instalando extensiones...',
	'iTopHub:Landing:Status' => 'Estatus de Instalación',
	'iTopHub:LandingWelcome' => '¡Felicidades! Las siguientes extensiones fueron descargadas de iTop Hub e instaladas en su '.ITOP_APPLICATION_SHORT.'.',
	'iTopHub:NoExtensionInThisCategory' => 'No hay extensiones en está categoría',
	'iTopHub:NoExtensionInThisCategory+' => 'Navegue en iTop Hub para encontrar aquellas que le ayuden a personalizar y adaptar '.ITOP_APPLICATION_SHORT.' a sus procesos !',
	'iTopHub:OpenInNewWindow' => 'Abrir iTop Hub en una nueva ventana',
	'iTopHub:Uncompressing' => 'Descomprimiendo extensiones...',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-hub-connector/dictionaries/es_cr.dict.itop-hub-connector.php <==
<?php
/**
 * Spanish Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 * @notas       Utilizar codificación UTF-8 para mostrar acentos y otros caracteres especiales 
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'Menu:iTopHub' => 'iTop Hub',
	'Menu:iTopHub:Register' => 'Conectar a iTop Hub',
	'Menu:iTopHub:Register+' => 'Ir a iTop Hub para actualizar su instancia de '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:Register:Description' => '<p>Obtenga acceso a la plataforma comunitaria iTop Hub!<br>Encuentre todo el contenido e información que necesite, adminitre sus instancias a través de herramientas personalizadas e instale más extensiones.<br><br>Mediante la conexión al Hub desde esta página, usted compartirá información acerca de esta instancia de '.ITOP_APPLICATION_SHORT.' en el Hub.</p>',
	'Menu:iTopHub:MyExtensions' => 'Extensiones instaladas',
	'Menu:iTopHub:MyExtensions+' => 'Vea la lista de extensiones instalada en esta instancia de '.ITOP_APPLICATION_SHORT,
	'Menu:iTopHub:BrowseExtensions' => 'Obtener extensiones de iTop Hub',
	'Menu:iTopHub:BrowseExtensions+' => 'Navegue por más extensiones en iTop Hub',
	'Menu:iTopHub:BrowseExtensions:Description' => '<p>Vea en "iTop Hub’s store", su único lugar para encontrar extensiones de '.ITOP_APPLICATION_SHORT.'.<br>Encuentre aquellas que le ayuden a personalizar y adaptar '.ITOP_APPLICATION_SHORT.' a sus procesos.<br><br>Mediante la conexión al Hub desde esta página, usted compartirá información acerca de esta instancia de '.ITOP_APPLICATION_SHORT.' en el Hub.</p>',
	'iTopHub:GoBtn' => 'Ir a iTop Hub',
	'iTopHub:CloseBtn' => 'Cerrar',
	'iTopHub:GoBtn:Tooltip' => 'Ir a www.itophub.io',
	'iTopHub:OpenInNewWindow' => 'Abrir iTop Hub en una nueva ventana',
	'iTopHub:AutoSubmit' => 'No me pregunte otra vez. Siguiente ocasión ir automáticamente a iTop Hub.',
	'UI:About:RemoteExtensionSource' => 'iTop Hub',
	'iTopHub:Explanation' => 'Dando click a este botón, usted será redireccionado a iTop Hub.',
	'iTopHub:BackupFreeDiskSpaceIn' => '%1$s espacio libre en disco en %2$s.',
	'iTopHub:FailedToCheckFreeDiskSpace' => 'Falló en revisar disponibilidad de espacio libre en disco.',
	'iTopHub:BackupOk' => 'Respaldo Ok.',
	'iTopHub:BackupFailed' => 'Respaldo Fallido!',
	'iTopHub:Landing:Status' => 'Estatus de Instalación',
	'iTopHub:Landing:Install' => 'Instalando extensiones...',
	'iTopHub:CompiledOK' => 'Compilación éxitosa.',
	'iTopHub:ConfigurationSafelyReverted' => 'Error detectado durante la instalación!<br>La configuración de '.ITOP_APPLICATION_SHORT.' NO fue modificada.',
	'iTopHub:FailAuthent' => 'Autenticación fallida para esta acciónn.',
	'iTopHub:InstalledExtensions' => 'Extensiones instaladas en esta instancia',
	'iTopHub:ExtensionCategory:Manual' => 'Extensiones instaladas manualmente',
	'iTopHub:ExtensionCategory:Manual+' => 'Las siguientes extensiones fueron instaladas copiandolas manualmente en el directorio %1$s de '.ITOP_APPLICATION_SHORT.':',
	'iTopHub:ExtensionCategory:Remote' => 'Extensiones instaladas desde iTop Hub',
	'iTopHub:ExtensionCategory:Remote+' => 'Las siguientes extensiones fueron instaladas de iTop Hub:',
	'iTopHub:NoExtensionInThisCategory' => 'No hay extensiones en está categoría',
	'iTopHub:NoExtensionInThisCategory+' => 'Navegue en iTop Hub para encontrar aquellas que le ayuden a personalizar y adaptar '.ITOP_APPLICATION_SHORT.' a sus procesos !',
	'iTopHub:ExtensionNotInstalled' => 'No instalada',
	'iTopHub:GetMoreExtensions' => 'Obtener extensiones de iTop Hub...',
	'iTopHub:LandingWelcome' => '¡Felicidades! Las siguientes extensiones fueron descargadas de iTop Hub e instaladas en su '.ITOP_APPLICATION_SHORT.'.',
	'iTopHub:GoBackToITopBtn' => 'Regresar a '.ITOP_APPLICATION_SHORT,
	'iTopHub:Uncompressing' => 'Descomprimiendo extensiones...',
	'iTopHub:InstallationWelcome' => 'Instalación de las extensiones descargadas de iTop Hub',
	'iTopHub:DBBackupLabel' => 'Respaldo de Instancia',
	'iTopHub:DBBackupSentence' => 'Realice un respaldo de la base de datos y configuración de '.ITOP_APPLICATION_SHORT.' antes de actualizar.',
	'iTopHub:DeployBtn' => 'Instalar !',
	'iTopHub:DatabaseBackupProgress' => 'Respaldo de Instancia...',
	'iTopHub:InstallationEffect:Install' => 'Version: %1$s será instalada.',
	'iTopHub:InstallationEffect:NoChange' => 'Version: %1$s ya está instalada. Nada por cambiar.',
	'iTopHub:InstallationEffect:Upgrade' => 'Se <b>actualizará</b> de la versión %1$s a la versión %2$s.',
	'iTopHub:InstallationEffect:Downgrade' => 'Se <b>DEGRADARÄ</b> de la versión %1$s a la versión %2$s.',
	'iTopHub:InstallationProgress:DatabaseBackup' => 'Respaldo de Instancia de '.ITOP_APPLICATION_SHORT.'...',
	'iTopHub:InstallationProgress:ExtensionsInstallation' => 'Instalación de extensiones',
	'iTopHub:InstallationEffect:MissingDependencies' => 'Esta extensión no puede ser instalad porque no cumple con las dependencias.',
	'iTopHub:InstallationEffect:MissingDependencies_Details' => 'La extensión require el/los módulo(s): %1$s',
	'iTopHub:InstallationProgress:InstallationSuccessful' => '¡Instalación éxitosa!',
	'iTopHub:InstallationStatus:Installed_Version' => '%1$s versión: %2$s.',
	'iTopHub:InstallationStatus:Installed' => 'Instalada',
	'iTopHub:InstallationStatus:Version_NotInstalled' => 'Versión %1$s <b>NO</b> está instalada.',
));
